@@ -5,7 +5,7 @@ use nxui::window::Frame;
 fn main() {
     nxui::initialize();
     match MessageBox::new("Hello NXUI!", "This is a test", DS_INFORMATION, BS_YESNO)
-        .show(Frame::default())
+        .show()
     {
         DR_YES => {
             MessageBox::new(
@@ -14,7 +14,7 @@ fn main() {
                 DS_INFORMATION,
                 BS_YESNO,
             )
-            .show(Frame::default());
+            .show();
         }
 
         DR_NO => {
@@ -24,7 +24,7 @@ fn main() {
                 DS_INFORMATION,
                 BS_YESNO,
             )
-            .show(Frame::default());
+            .show();
         }
 
         _ => {}
