@@ -12,7 +12,7 @@ fn main() {
         DS_INFORMATION,
         BS_OK,
     )
-    .show(Frame::default());
+    .show();
     let result = SaveFileDialog::new("Save File Example", FC_NONE).show();
     MessageBox::new(
         "FileChooser Result",
@@ -20,5 +20,5 @@ fn main() {
         DS_INFORMATION,
         BS_OK,
     )
-    .show(Frame::default());
+    .show();
 }
