@@ -10,5 +10,5 @@ fn main() {
         DS_QUESTION,
         BS_YESNO,
     )
-    .show(Frame::default());
+    .show();
 }
