@@ -4,16 +4,16 @@ use nxui::window::Frame;
 
 fn main() {
     nxui::initialize();
-    MessageBox::new("None Dialog", "None Dialog", DS_NONE, BS_OK).show(Frame::default());
+    MessageBox::new("None Dialog", "None Dialog", DS_NONE, BS_OK).show();
     MessageBox::new(
         "Information Dialog",
         "Information Dialog",
         DS_INFORMATION,
         BS_OK,
     )
-    .show(Frame::default());
+    .show();
     MessageBox::new("Question Dialog", "Question Dialog", DS_QUESTION, BS_OK)
-        .show(Frame::default());
-    MessageBox::new("Warning Dialog", "Warning Dialog", DS_WARNING, BS_OK).show(Frame::default());
-    MessageBox::new("Error Dialog", "Error Dialog", DS_ERROR, BS_OK).show(Frame::default());
+        .show();
+    MessageBox::new("Warning Dialog", "Warning Dialog", DS_WARNING, BS_OK).show();
+    MessageBox::new("Error Dialog", "Error Dialog", DS_ERROR, BS_OK).show();
 }
