@@ -1,19 +1,17 @@
+//! Sample window
+
 use crate::io::storage::Storage;
 use crate::natives_and_messaging::*;
 use crate::widget::menu::Menu;
 use crate::widget::menubar::MenuBar;
 use crate::widget::menuitem::MenuItem;
-use crate::window::{Application, Frame, Attributes};
+use crate::window::{Application, Attributes, Frame};
 
-pub struct DemoWindow {
-
-}
+pub struct DemoWindow {}
 
 impl DemoWindow {
     pub fn new() -> Self {
-        Self {
-
-        }
+        Self {}
     }
 }
 
@@ -23,19 +21,30 @@ impl Application for DemoWindow {
     }
 
     fn attributes(&self) -> Attributes {
-        Attributes::new(WS_NORMAL, "NXUI Window".to_string(),"io.github.lattesyobon.demo".to_string(),1280, 750, 100, 100)
+        Attributes::new(
+            WS_NORMAL,
+            "NXUI Window".to_string(),
+            "io.github.lattesyobon.demo".to_string(),
+            1280,
+            750,
+            100,
+            100,
+        )
     }
 
     fn is_child_window(&self) -> bool {
         false
     }
 
-    fn startup(&self,storage: Storage) {
+    fn startup(&self, storage: Storage) {
         println!("Startup!");
-        println!("Config dir is {}",storage.get_config_dir().as_os_str().to_str().unwrap());
+        println!(
+            "Config dir is {}",
+            storage.get_config_dir().as_os_str().to_str().unwrap()
+        );
     }
 
-    fn ui(&self,frame: &Frame) {
+    fn ui(&self, frame: &Frame) {
         let menubar = MenuBar::new();
         let file = MenuItem::new("File");
         let new = Menu::new("New...");
@@ -51,4 +60,4 @@ impl Application for DemoWindow {
     fn exit(&self) {
         println!("Exit Application");
     }
-}
\ No newline at end of file
+}
