@@ -20,7 +20,22 @@ impl Icon {
         Self { icon: hIcon }
     }
 
-    pub fn get_icon(&self) -> windows_sys::Win32::UI::WindowsAndMessaging::HICON {
+    #[no_mangle] pub extern "C" fn new_icon(name: String) -> Self {
+        use windows_sys::Win32::UI::WindowsAndMessaging::*;
+        let hIcon = unsafe {
+            LoadImageA(
+                0,
+                format!("{}\0", name).as_ptr(),
+                IMAGE_ICON,
+                0,
+                0,
+                LR_SHARED | LR_LOADFROMFILE,
+            )
+        };
+        Self { icon: hIcon }
+    }
+
+    #[no_mangle] pub extern "C" fn get_icon(&self) -> windows_sys::Win32::UI::WindowsAndMessaging::HICON {
         self.icon
     }
 }
@@ -43,7 +58,11 @@ impl Icon {
         Self { file_name: name }
     }
 
-    pub fn get_file_name(self) -> String {
+    #[no_mangle] pub extern "C" fn new_icon(name: String) -> Self {
+        Self { file_name: name }
+    }
+
+    #[no_mangle] pub extern "C" fn get_file_name(self) -> String {
         self.file_name
     }
 }
