@@ -3,6 +3,7 @@
 
 use crate::window::Frame;
 use std::iter::once;
+use crate::natives_and_messaging::*;
 
 #[cfg(windows)]
 pub struct MessageBox<'a> {
@@ -34,8 +35,8 @@ impl<'a> MessageBox<'a> {
     pub fn new(
         title: &'a str,
         message: &'a str,
-        style: windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE,
-        button_style: windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE,
+        style: MessageBoxStyle,
+        button_style: ButtonStyle,
     ) -> Self {
         Self {
             title,
@@ -57,8 +58,7 @@ impl<'a> MessageBox<'a> {
     /// }
     /// ```
     pub fn show(
-        &self,
-        frame: Frame,
+        &self
     ) -> windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_RESULT {
         unsafe {
             use windows_sys::{
@@ -69,10 +69,9 @@ impl<'a> MessageBox<'a> {
             SetEvent(event);
             WaitForSingleObject(event, 0);
             CloseHandle(event);
-            info!("HANDLE: {}", frame.get_window());
 
             let result = MessageBoxW(
-                frame.get_window(),
+                0,
                 self.message
                     .encode_utf16()
                     .chain(once(0))
@@ -97,8 +96,8 @@ impl<'a> MessageBox<'a> {
     pub fn new(
         title: &'a str,
         message: &'a str,
-        style: gtk::MessageType,
-        button_style: gtk::ButtonsType,
+        style: MessageBoxStyle,
+        button_style: ButtonStyle,
     ) -> Self {
         Self {
             title,
@@ -119,7 +118,7 @@ impl<'a> MessageBox<'a> {
     ///     MessageBox::new("Hello NXUI!".to_string(),"This is a test".to_string(),DIALOGSTYLE_INFORMATION,BUTTONSTYLE_OK).show();
     /// }
     /// ```
-    pub fn show(&self, frame: Frame) -> gtk::ResponseType {
+    pub fn show(&self) -> gtk::ResponseType {
         use gtk::prelude::*;
         gtk::init().expect("Failed to initialize gtk.");
         let window = frame.get_window();
