@@ -6,6 +6,7 @@ use crate::natives_and_messaging::*;
 use crate::window::{Application, Frame};
 
 #[cfg(windows)]
+#[deprecated(since="0.16.25", note="Use the new Window Struct")]
 /// Run nxui::window::Application
 #[no_mangle] pub extern "C" fn create_new_app(application: Box<dyn Application>) {
     // Get window title
@@ -78,7 +79,7 @@ use crate::window::{Application, Frame};
             std::ptr::null_mut(),
         );
         if win == 0 {
-            MessageBox::new("NXUI Error", "NXUI Error - Code 0001\rWindow could not be initialized\r \rDetailed information:\rPanicked at nxui::nxui::create_new_app()\rTo resolve this error, contact the application developer or\rPlease report at https://github.com/LatteSyobon/nxui/issues", DS_ERROR, BS_OK).show(Frame::default());
+            MessageBox::new("NXUI Error", "NXUI Error - Code 0001\rWindow could not be initialized\r \rDetailed information:\rPanicked at nxui::nxui::create_new_app()\rTo resolve this error, contact the application developer or\rPlease report at https://github.com/LatteSyobon/nxui/issues", DS_ERROR, BS_OK).show();
             panic!("Window could not be initialized");
         }
 
@@ -101,6 +102,7 @@ use crate::window::{Application, Frame};
 }
 
 #[cfg(unix)]
+#[deprecated(since="0.16.25", note="Use the new Window Struct")]
 /// Run nxui::window::Application
 #[no_mangle] pub extern "C" fn create_new_app(application: Box<dyn Application>) {
     // Get window title
