@@ -29,3 +29,11 @@ use winapi::um::winnt::PWSTR;
         String::from_utf16_lossy(array)
     }
 }
+
+pub fn open_link_in_browser(url: &str) {
+    webbrowser::open(url);
+}
+
+pub fn get_version() -> &'static str {
+    std::env!("CARGO_PKG_VERSION")
+}
