@@ -1,29 +1,21 @@
 //! Horizontal widget layout.
 
 #[cfg(windows)]
-pub struct HBox {
-
-}
+pub struct HBox {}
 
 #[cfg(windows)]
 impl HBox {
     pub fn new() -> Self {
-        Self {
-
-        }
+        Self {}
     }
 }
 
 #[cfg(unix)]
-pub struct HBox {
-
-}
+pub struct HBox {}
 
 #[cfg(unix)]
 impl HBox {
     pub fn new() -> Self {
-        Self {
-
-        }
+        Self {}
     }
-}
\ No newline at end of file
+}
