@@ -1,11 +1,13 @@
-use std::iter::once;
+//! Widgets that can be placed in Menu and MenuItem.
+
 use crate::widget::menu::Menu;
+use std::iter::once;
 
 #[cfg(windows)]
-#[derive(Copy,Clone)]
+#[derive(Clone)]
 pub struct MenuItem<'a> {
     menu: windows_sys::Win32::UI::WindowsAndMessaging::HMENU,
-    title:  &'a str
+    title: &'a str,
 }
 #[cfg(windows)]
 impl<'a> MenuItem<'a> {
@@ -13,24 +15,39 @@ impl<'a> MenuItem<'a> {
         use windows_sys::Win32::UI::WindowsAndMessaging::CreatePopupMenu;
         unsafe {
             let menu = CreatePopupMenu();
-            Self {
-                menu,
-                title
-            }
+            Self { menu, title }
         }
     }
 
-    pub fn add_menuitem(&self,item: MenuItem) {
+    pub fn add_menuitem(&self, item: MenuItem) {
         use windows_sys::Win32::UI::WindowsAndMessaging::*;
         unsafe {
-            AppendMenuW(self.menu, MFT_STRING, item.get_menu() as usize, item.get_title().encode_utf16().chain(once(0)).collect::<Vec<u16>>().as_mut_ptr());
+            AppendMenuW(
+                self.menu,
+                MFT_STRING,
+                item.get_menu() as usize,
+                item.get_title()
+                    .encode_utf16()
+                    .chain(once(0))
+                    .collect::<Vec<u16>>()
+                    .as_mut_ptr(),
+            );
         }
     }
 
-    pub fn add_menu(&self,item: Menu) {
+    pub fn add_menu(&self, item: Menu) {
         use windows_sys::Win32::UI::WindowsAndMessaging::*;
         unsafe {
-            AppendMenuW(self.menu, MF_POPUP|MFT_STRING, item.get_menu() as usize, item.get_title().encode_utf16().chain(once(0)).collect::<Vec<u16>>().as_mut_ptr());
+            AppendMenuW(
+                self.menu,
+                MF_POPUP | MFT_STRING,
+                item.get_menu() as usize,
+                item.get_title()
+                    .encode_utf16()
+                    .chain(once(0))
+                    .collect::<Vec<u16>>()
+                    .as_mut_ptr(),
+            );
         }
     }
 
@@ -54,26 +71,23 @@ impl<'a> MenuItem<'a> {
 #[derive(Clone)]
 pub struct MenuItem<'a> {
     menu: gtk::gio::MenuItem,
-    title:  &'a str
+    title: &'a str,
 }
 
 #[cfg(unix)]
 impl<'a> MenuItem<'a> {
     pub fn new(title: &'a str) -> Self {
         use gtk::gio::MenuItem;
-        let menu = MenuItem::new(Some(title),Some("win"));
-        Self {
-            menu,
-            title
-        }
+        let menu = MenuItem::new(Some(title), Some("win"));
+        Self { menu, title }
     }
 
-    pub fn add_menuitem(&self,item: MenuItem) {
+    pub fn add_menuitem(&self, item: MenuItem) {
         use gtk::prelude::*;
         //self.menu.set_submenu(Some(&item.get_menu()));
     }
 
-    pub fn add_menu(&self,item: Menu) {
+    pub fn add_menu(&self, item: Menu) {
         use gtk::prelude::*;
         self.menu.set_submenu(Some(&item.get_menu()));
     }
@@ -90,4 +104,4 @@ impl<'a> MenuItem<'a> {
     pub fn get_title(self) -> &'a str {
         self.title
     }
-}
\ No newline at end of file
+}
