@@ -12,3 +12,8 @@ pub mod menuitem;
 pub mod radiobutton;
 pub mod textedit;
 pub mod vbox;
+pub mod groupbox;
+
+pub trait NWidget {
+    fn get_handle(self) -> windows_sys::Win32::Foundation::HWND;
+}
