@@ -2,12 +2,15 @@
 
 use crate::graphic::icon::Icon;
 use crate::io::storage::Storage;
+use crate::natives_and_messaging::WindowStyle;
 use crate::widget::menubar::MenuBar;
 
 pub mod dialog;
+pub mod window;
 
 #[cfg(windows)]
 #[derive(Clone)]
+#[deprecated(since="0.16.25", note="Use the new Window Struct")]
 pub struct Frame {
     /// Window body
     handle: windows_sys::Win32::Foundation::HWND
@@ -149,6 +152,7 @@ impl Default for Frame {
 }
 
 #[cfg(windows)]
+#[derive(Clone)]
 pub struct Attributes {
     pub style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,
     pub title: String,
@@ -162,7 +166,7 @@ pub struct Attributes {
 #[cfg(windows)]
 impl Attributes {
     pub fn new(
-        style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE,
+        style: WindowStyle,
         title: String,
         app_id: String,
         width: i32,
@@ -183,6 +187,7 @@ impl Attributes {
 }
 
 #[cfg(windows)]
+#[deprecated(since="0.16.25", note="Use the new Window Struct")]
 pub struct AdvancedOptions {
     advanced_style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE,
     background_color: i32
@@ -213,6 +218,7 @@ impl Default for AdvancedOptions {
 }
 
 #[cfg(windows)]
+#[deprecated(since="0.16.25", note="Use the new Window Struct")]
 pub trait Application {
     /// Returns the name of the application.
     fn app_name(&self) -> String;
@@ -236,6 +242,7 @@ pub trait Application {
 
 #[cfg(unix)]
 #[derive(Clone)]
+#[deprecated(since="0.16.25", note="Use the new Window Struct")]
 pub struct Frame {
     /// Window body
     handle: gtk::ApplicationWindow,
@@ -379,6 +386,7 @@ impl Attributes {
 
 #[cfg(unix)]
 #[derive(Clone)]
+#[deprecated(since="0.16.25", note="Use the new Window Struct")]
 pub struct AdvancedOptions {
     advanced_style: gtk::gdk::WindowTypeHint,
 }
@@ -404,6 +412,7 @@ impl Default for AdvancedOptions {
 }
 
 #[cfg(unix)]
+#[deprecated(since="0.16.25", note="Use the new Window Struct")]
 pub trait Application {
     /// Returns the name of the window.
     fn app_name(&self) -> String;
